@@ -19,7 +19,7 @@ import re
 from .utils import F
 from . import utils
 
-__version__ = '1.1.4'
+__version__ = '1.2.0'
 
 logger = logging.getLogger(__name__)
 
@@ -322,20 +322,20 @@ class CrossEnvBuilder(venv.EnvBuilder):
         self.host_version = self.host_sysconfigdata.build_time_vars['VERSION']
         self.host_gnu_type = self.host_sysconfigdata.build_time_vars['HOST_GNU_TYPE']
 
-        # Ask the makefile a few questions too
-        if not os.path.exists(self.host_makefile):
-            raise FileNotFoundError("Cannot find Makefile")
-
         self.host_platform = None
-        with open(self.host_makefile, 'r') as fp:
-            lines = list(fp.readlines())
-        for line in lines:
-            line = line.strip()
-            if line.startswith('_PYTHON_HOST_PLATFORM='):
-                host_platform = line.split('=',1)[-1].strip()
-                if host_platform:
-                    self.host_platform = host_platform
-                break
+        # Ask the makefile a few questions too
+        if os.path.exists(self.host_makefile):
+            with open(self.host_makefile, 'r') as fp:
+                lines = list(fp.readlines())
+            for line in lines:
+                line = line.strip()
+                if line.startswith('_PYTHON_HOST_PLATFORM='):
+                    host_platform = line.split('=',1)[-1].strip()
+                    if host_platform:
+                        self.host_platform = host_platform
+                    break
+        else:
+            lines = []
 
         if self.host_platform is None:
             # It was probably natively compiled, but not necessarily for this
@@ -369,27 +369,38 @@ class CrossEnvBuilder(venv.EnvBuilder):
 
         def run_compiler(arg):
             cmdline = self.host_cc + [arg]
-            try:
-                return subprocess.check_output(cmdline, universal_newlines=True)
-            except (subprocess.CalledProcessError, FileNotFoundError):
-                return None
+            return subprocess.run(cmdline,
+                                  universal_newlines=True,
+                                  stdout=subprocess.PIPE,
+                                  stderr=subprocess.PIPE)
 
-        if run_compiler('--version') is None:
-            # I guess we could continue...but why?
+        if not shutil.which(self.host_cc[0]):
             raise RuntimeError(
-                "Cannot run cross-compiler (%r)! Extension modules won't "
+                "Cannot find cross-compiler (%r)! Extension modules won't "
                 "build! Use --cc to correct." % ' '.join(self.host_cc))
+
+        # Check that it runs, but failing this is a warning. Some compilers,
+        # like QNX's qcc, do not have useful arguments we can pass to get a
+        # successful return value.
+        res = run_compiler('--version')
+        if res.returncode != 0:
+            logger.warning(
+                "Test run of %r exited with code %d: %s" % (
+                    self.host_cc, res.returncode, res.stderr))
+            # If it doesn't have --version, it certainly won't have
+            # -print-sysroot or -dumpmachine
             return
 
         # TODO: Clang doesn't have this option
         if self.host_sysroot is None:
-            self.host_sysroot = run_compiler('-print-sysroot')
-            if self.host_sysroot:
-                self.host_sysroot = self.host_sysroot.strip()
+            res = run_compiler('-print-sysroot')
+            if res.returncode == 0:
+                self.host_sysroot = res.stdout.strip()
 
         # Sanity check that this is the right compiler. (See #24, #27.)
-        found_triple = run_compiler('-dumpmachine').strip().strip()
-        if found_triple:
+        res = run_compiler('-dumpmachine')
+        found_triple = res.stdout.strip()
+        if res.returncode == 0 and found_triple:
             expected = self.host_sysconfigdata.build_time_vars['HOST_GNU_TYPE']
             if not self._compare_triples(found_triple, expected):
                 logger.warning("The cross-compiler (%r) does not appear to be "
